@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "russian-techwriter" "1.0.2"
+(define-package "russian-techwriter" "20251010.538"
   "Input methods for Russian technical writers."
   ()
   :url "https://github.com/dunmaksim/emacs-russian-techwriter-input-method"
-  :commit "10a82cb6e92db1e7c5c86d024a74a718d8d17005"
-  :revdesc "10a82cb6e92d"
+  :commit "a568c8a3f409f7f9b5cb12143f277af78fef9a26"
+  :revdesc "a568c8a3f409"
   :keywords '("multilingual" "input method" "cyrillic" "i18n")
   :authors '(("Maxim Dunaevskii" . "dunmaksim@yandex.ru")))
